@@ -90,6 +90,10 @@ class AppConfig(object):
 
     def _build_required_factories(self, required_modules=[]):
         for module in required_modules:
+            if self._is_module_from_current_app(module):
+                continue
+
+            # Find the existed module on the list.
             existed_module = self._find_factory_required_module_by_app(app_name=module.app_name)
 
             if existed_module:
@@ -115,6 +119,9 @@ class AppConfig(object):
 
         return required_module
 
+    def _is_module_from_current_app(self, module):
+        return module.app_name.lower() == self.name.lower()
+
     def to_json(self) -> dict:
         """
         Dump this class to JSON.
