@@ -22,7 +22,7 @@ class ModelMeta(object):
 
     # Require libs for factory
     factory_required_libs: [str] = []
-    factory_required_modules: [str] = []
+    factory_required_modules: [object] = []
 
     def __init__(self, model=None):
         self.model = model
@@ -81,15 +81,14 @@ class ModelMeta(object):
 
             # add required modules and libs
             self.factory_required_libs += factory.import_libs
-            self.factory_required_modules += factory.required_factories
+            if factory.required_factory is not None:
+                self.factory_required_modules.append(factory.required_factory)
 
             self.fields.append(field)
 
         # make the lists unique
         self.factory_required_libs = list(
             dict.fromkeys(self.factory_required_libs))
-        self.factory_required_modules = list(
-            dict.fromkeys(self.factory_required_modules))
 
         return self
 
